==> haskell-http-client-0.7.19-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client
version:              0.7.19
visibility:           public
id:                   http-client-0.7.19-2XRSbtk4hrv80aqsDMrhLG
key:                  http-client-0.7.19-2XRSbtk4hrv80aqsDMrhLG
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  7022a762c2ccdd48f0d1b553cd001f94
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-0.7.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-0.7.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-0.7.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client
hs-libraries:         HShttp-client-0.7.19-2XRSbtk4hrv80aqsDMrhLG
depends:
    array-0.5.4.0 async-2.2.5-Fwc3ABGHG7o8WWC3l3QDRi base-4.17.2.1
    base64-bytestring-1.2.1.0-ITj2xakY1ml2q5A6QmvnkU
    blaze-builder-0.4.4-6Kuq6wnWuSiCILCubQnlxM bytestring-0.11.5.3
    case-insensitive-1.2.1.0-fOfWi0N5mt64FY3ZUEjlf containers-0.6.7
    cookie-0.4.6-GZOZqzUDn152OuhEYvht8s deepseq-1.4.8.0
    exceptions-0.10.5 filepath-1.4.2.2 ghc-prim-0.9.1
    http-types-0.12.4-DI0pM0gIACkLbu0K6LN6Y6
    iproute-1.7.15-LguWZ20tMlFF9xdP1duB2d
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    network-3.1.4.0-1Bok7DDOmdQ7OlyZLPDJ7H
    network-uri-2.6.4.2-4guMK9PpDjI4XiQikAf4nE
    random-1.2.1.3-2cudg871s2f2tL4YjAU8WJ stm-2.5.1.0
    streaming-commons-0.2.3.0-q2ZN2jYU5KLmG1DmYZNkR text-2.0.2
    time-1.12.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.7.19-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client
version:              0.7.19
visibility:           public
id:                   http-client-0.7.19-4PBxl7ykGvY1A1M3m4syiA
key:                  http-client-0.7.19-4PBxl7ykGvY1A1M3m4syiA
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  0d5623550a1885df9c3d38272c757181
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-0.7.19
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-0.7.19
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-0.7.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client
hs-libraries:         HShttp-client-0.7.19-4PBxl7ykGvY1A1M3m4syiA
depends:
    array-0.5.4.0 async-2.2.5-HMp4lCE5MFwDsdQT9P7pHP base-4.17.2.1
    base64-bytestring-1.2.1.0-3cCVQioh572KzPLHpOFxfQ
    blaze-builder-0.4.4-8zU52EanQG02I2y4ER5AE9 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KEDJwVxaVqqI97A4XPwej0 containers-0.6.7
    cookie-0.4.6-GZOZqzUDn152OuhEYvht8s deepseq-1.4.8.0
    exceptions-0.10.5 filepath-1.4.2.2 ghc-prim-0.9.1
    http-types-0.12.4-5NSSMgOt7vT4e8131JaEsZ
    iproute-1.7.15-KzwZ0AdHV5x2K8MnCURfbh
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    network-3.1.4.0-HNOpCulLIRrH0UV3cvGeTA
    network-uri-2.6.4.2-4Or7NcWT1BFGL9jaSnxRbG
    random-1.2.1.3-1ICINoe1N4e7cLBAPqefIx stm-2.5.1.0
    streaming-commons-0.2.3.0-55fGl12L6MX9VRdkOBDzGS text-2.0.2
    time-1.12.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
